@@ -1,8 +1,6 @@
 // -*- Mode: C++; tab-width: 2; -*-
 // vi: set ts=2:
 //
-// $Id: debug.h,v 1.10 2004/02/23 21:35:17 anhi Exp $
-//
 
 #ifndef BALL_COMMON_DEBUG_H
 #define BALL_COMMON_DEBUG_H
@@ -18,6 +16,7 @@
 #endif
 
 #include <string>
+#include <cstring>
 
 #ifdef BALL_DEBUG
 
@@ -25,7 +24,7 @@
 	if (!(condition))\
 	{\
 		Exception::Precondition e(__FILE__, __LINE__, #condition);\
-		if (message != "")\
+		if (strcmp(message, "") != 0)\
 		{\
       ::std::string tmp(e.getMessage());\
 			tmp += ::std::string(message);\
@@ -38,7 +37,7 @@
 	if (!(condition))\
 	{\
 		Exception::Postcondition e(__FILE__, __LINE__, #condition);\
-		if (message != "")\
+		if (strcmp(message, "") != 0)\
 		{\
       std::string tmp(e.getMessage());\
 			tmp += std::string(message);\
