@@ -268,6 +268,10 @@ namespace BALL
 				is returned.
 		*/
 		string getString() const;
+		
+		/** Converts the data contained in this NamedProperty to a string and returns it. \n
+		Note that this function is intended as a convenience and does NOT depend on the type of the data (in constrast to getString()). */
+		string toString() const;
 
 		//@}
 
@@ -305,6 +309,8 @@ namespace BALL
 
 	};
 
+	typedef std::vector<NamedProperty>::iterator NamedPropertyIterator;
+
 	/**	Property Manager class.
 			This class manages properties of a class.
 			A property can be seen as easy way to extend the
@@ -562,6 +568,12 @@ namespace BALL
 		*/
 		const NamedProperty& getProperty(const string& name) const;
 
+		/** Return an iterator to the first NamedProperty stored in this container. */
+		NamedPropertyIterator beginNamedProperty();
+
+		/** Return an iterator past the last NamedProperty stored in this container. */
+		NamedPropertyIterator endNamedProperty();
+
 		/**	Remove a named property.
 				If the named property <tt>name</tt> does exist, it is remove from
 				the array of properties.
