@@ -25,12 +25,23 @@
 #	include <BALL/MATHS/vector3.h>
 #endif
 
-#ifndef BALL_DATATYPE_LIST_H
-# include <BALL/DATATYPE/list.h>
+#ifdef BALL_HAS_GNU_SLIST
+#include <ext/slist>
+#else
+#include <list>
 #endif
 
+#include <algorithm>
+
 namespace BALL 
 {
+	namespace __private
+	{
+		extern const char BALL_EXPORT neighbour_table_[27][3];
+	}
+
+	template <typename Item> class HashGrid3;
+
 	/**	\defgroup GenericHash3D Three-dimensional Hash Grid
     	\ingroup  GenericHash
 	*/
@@ -54,13 +65,7 @@ namespace BALL
 		//@{
 
 		///	Default constructor
-		HashGridBox3();
-			
-		/// Copy constructor
-		HashGridBox3(const HashGridBox3& grid_box, bool deep = true);
-
-		/// Destructor
-		~HashGridBox3();
+		HashGridBox3(HashGrid3<Item>* parent);
 
 		/// Clears the grid box
 		void clear();
@@ -75,19 +80,18 @@ namespace BALL
 		*/
 		//@{
 
-		///
-		void set(const HashGridBox3& box,bool /* deep */ = true)
-			throw(Exception::NotImplemented);
-
-		///
-		const HashGridBox3& operator = (const HashGridBox3& box)
-			throw(Exception::NotImplemented);
-
 		//@}
 		/**	@name	Accessors 
 		*/
 		//@{
 
+		void setParent(HashGrid3<Item>* p);
+
+		/**
+		 * Return the indices of this box in the parent HashGrid
+		 */
+		void getIndices(Position& x, Position& y, Position& z);
+
 		/** Find an item in the item list of this grid box.
 				@param item the item to be searched for
 				@return a pointer to the desired item or a NULL pointer, if the 
@@ -176,28 +180,6 @@ namespace BALL
 		/** @name	External Iterators 
 		*/
 		//@{
-
-		/// ?????
-		class DataItem
-		{
-			public:
-		
-			DataItem(const Item& item, DataItem* next)
-			:	item_(item),
-				previous_(0),
-				next_(next)
-			{
-				if (next_ != 0)
-				{
-					next_->previous_ = this;
-				}
-			}
-
-			Item 			item_;
-			DataItem* previous_;
-			DataItem* next_;
-		};
-
 		typedef Position BoxIteratorPosition;
 		
 		class BoxIteratorTraits
@@ -209,29 +191,24 @@ namespace BALL
 			virtual ~BoxIteratorTraits() throw () {}
 
 			BoxIteratorTraits()
-				:	bound_(0),
-					position_(0)
+				: bound_(0),
+					position_(0),
+					x_(0), y_(0), z_(0)
 			{
 			}
-				
+
 			BoxIteratorTraits(const HashGridBox3& box)
-				:	bound_((HashGridBox3 *)&box),
+				: bound_((HashGridBox3 *)&box),
 					position_(0)
 			{
+				bound_->getIndices(x_, y_, z_);
 			}
-				
+
 			BoxIteratorTraits(const BoxIteratorTraits& traits, bool /* deep */ = true)
 				:	bound_(traits.bound_),
 					position_(traits.position_)
 			{
 			}
-				
-			const BoxIteratorTraits& operator = (const BoxIteratorTraits& traits)
-			{
-				bound_ = traits.bound_;
-				position_ = traits.position_;
-				return *this;
-			}
 
 			HashGridBox3* getContainer()
 			{
@@ -282,6 +259,7 @@ namespace BALL
 			void toBegin()
 			{
 				position_ = 0;
+				cur_box_ = bound_;
 			}
 
 			bool isBegin() const
@@ -292,6 +270,7 @@ namespace BALL
 			void toEnd()
 			{
 				position_ = 27;
+				cur_box_ = 0;
 			}
 
 			bool isEnd() const
@@ -301,19 +280,22 @@ namespace BALL
 
 			HashGridBox3<Item>& getData()
 			{
-				return *bound_->neighbours[position_];
+				return *cur_box_;
 			}
 
 			const HashGridBox3<Item>& getData() const
 			{
-				return *bound_->neighbours[position_];
+				return *cur_box_;
 			}
 
 			void forward()
 			{
 				++position_;
 				// iterate to the next existing box
-				while (position_<27 && !(bound_->neighbours[position_]))
+				while (     position_ < 27
+				       && !(cur_box_ = bound_->parent->getBox(x_ + __private::neighbour_table_[position_][0],
+				                                              y_ + __private::neighbour_table_[position_][1],
+				                                              z_ + __private::neighbour_table_[position_][2])))
 				{
 					++position_;
 				}
@@ -322,7 +304,9 @@ namespace BALL
 			private:
 
 			HashGridBox3<Item> *bound_;
+			HashGridBox3<Item> *cur_box_;
 			BoxIteratorPosition position_;
+			Position x_, y_, z_;
 		};
 
 		friend class BoxIteratorTraits;
@@ -367,10 +351,15 @@ namespace BALL
 			return ConstBoxIterator::end(*this);
 		}
 
+#ifdef BALL_HAS_GNU_SLIST
+		typedef typename __gnu_cxx::slist<Item> DataContainer;
+#else
+		typedef typename std::list<Item> DataContainer;
+#endif
 
-		typedef DataItem* DataIteratorPosition;
+		typedef typename DataContainer::iterator DataIteratorPosition;
 		
-	class DataIteratorTraits
+		class DataIteratorTraits
 		{
 			public:
 
@@ -380,13 +369,13 @@ namespace BALL
 
 			DataIteratorTraits()
 			:	bound_(0),
-				position_(0)
+				position_()
 			{
 			}
 				
 			DataIteratorTraits(const HashGridBox3& box)
 			:	bound_((HashGridBox3 *)&box),
-				position_(0)
+				position_(bound_->data.begin())
 			{
 			}
 				
@@ -440,48 +429,48 @@ namespace BALL
 
 			bool isValid() const
 			{
-				return (bound_ != 0 && position_ != 0);
+				return (bound_ != 0 && position_ != bound_->data.end());
 			}
 
 			void invalidate()
 			{
 				bound_ = 0;
-				position_ = 0;
+				position_ = bound_->data.end();
 			}
 
 			void toBegin()
 			{
-				position_ = bound_->first_item_;
+				position_ = bound_->data.begin();
 			}
 
 			bool isBegin() const
 			{
-				return (position_ == bound_->first_item_);
+				return (position_ == bound_->data.begin());
 			}
 
 			void toEnd()
 			{
-				position_ = 0;
+				position_ = bound_->data.end();
 			}
 
 			bool isEnd() const
 			{
-				return (position_ == 0);
+				return (position_ == bound_->data.end());
 			}
 
 			Item& getData()
 			{
-				return position_->item_;
+				return *position_;
 			}
 
 			const Item& getData() const
 			{
-				return position_->item_;
+				return *position_;
 			}
 
 			void forward()
 			{
-				position_ = position_->next_;
+				++position_;
 			}
 	
 			private:
@@ -535,41 +524,21 @@ namespace BALL
 
 		//@}	
 
-		/// This array stores a pointer to the box itself and the 26 neighbours of the current box
-		HashGridBox3* neighbours[27];
-		//  private:
-	
-		DataItem* 					first_item_;
+		HashGrid3<Item>* parent;
+
+		DataContainer data;
 	};
 
 	template<typename Item>  
-	HashGridBox3<Item>::HashGridBox3()
-		:	first_item_(0)
+	HashGridBox3<Item>::HashGridBox3(HashGrid3<Item>* p)
+		: parent(p)
 	{
-		memset(neighbours, 0, 27*sizeof(HashGridBox3*));
-	}
-
-	template<typename Item>  
-	HashGridBox3<Item>::HashGridBox3(const HashGridBox3<Item>& box, bool deep)
-		:	first_item_(0)
-	{
-		set(box, deep);
-	}
-
-	template<typename Item>  
-	HashGridBox3<Item>::~HashGridBox3()
-	{
-		clear();
 	}
 
 	template<typename Item>  
 	void HashGridBox3<Item>::clear()
 	{
-		for (DataItem* next_item = 0; first_item_ != 0; first_item_ = next_item)
-		{
-			next_item = first_item_->next_;
-			delete first_item_;
-		}
+		data.clear();
 	}
 
 	template<typename Item>  
@@ -579,33 +548,27 @@ namespace BALL
 		clear();
 	}
 
-	template<typename Item>  
-	void HashGridBox3<Item>::set(const HashGridBox3<Item>& box,  bool deep)
-		throw(Exception::NotImplemented)
-  { 
-		// ????? - not implemented
-    throw Exception::NotImplemented(__FILE__, __LINE__);
-	}
- 
-	template<typename Item>  
-	BALL_INLINE 
-	const HashGridBox3<Item>& HashGridBox3<Item>::operator = (const HashGridBox3<Item>& box)
-		throw(Exception::NotImplemented)
+	template<typename Item>
+	BALL_INLINE void HashGridBox3<Item>::setParent(HashGrid3<Item>* p)
 	{
-		set(box);
-		
-		return *this;
+		parent = p;
+	}
+
+	template<typename Item>
+	BALL_INLINE
+	void HashGridBox3<Item>::getIndices(Position& x, Position& y, Position& z)
+	{
+		parent->getIndices(*this, x, y, z);
 	}
 
 	template<typename Item>  
 	Item* HashGridBox3<Item>::find(const Item& item)
 	{
-		for (DataItem* item_ptr= first_item_; item_ptr != 0; item_ptr = item_ptr->next_)
+		typename DataContainer::iterator found = std::find(data.begin(), data.end(), item);
+
+		if (found != data.end())
 		{
-			if (item_ptr->item_ == item)
-			{
-				return &(item_ptr->item_);
-			}
+			return &(*found);
 		}
 
 		return 0;
@@ -621,89 +584,59 @@ namespace BALL
 	template<typename Item>  
 	Size HashGridBox3<Item>::getSize() const
 	{
-		Size size = 0;
-
-		// count all items in the box
-		for (const DataItem* item = first_item_; item != 0; item = item->next_, size++) {};
-		
-		return size;
+		return data.size();
 	}
 
 	template<typename Item>  
 	BALL_INLINE 
 	void HashGridBox3<Item>::insert(const Item& item)
 	{
-		first_item_ = new DataItem(item, first_item_);
+		data.push_front(item);
 	}
 
 	template<typename Item>  
 	bool HashGridBox3<Item>::remove(const Item& item)
 	{
-		for (DataItem* item_ptr = first_item_; item_ptr != 0; item_ptr = item_ptr->next_)
+#ifdef BALL_HAS_GNU_SLIST
+		if(*data.begin() == item)
 		{
-			if (item_ptr->item_ == item)
+			data.pop_front();
+			return true;
+		}
+
+		DataIteratorPosition prev = data.begin();
+		DataIteratorPosition pos = prev;
+		for(++pos; pos != data.end(); ++pos)
+		{
+			if(*pos == item)
 			{
-				if (item_ptr == first_item_)
-				{
-					first_item_ = first_item_->next_;
-				}
-			
-				if (item_ptr->next_ != 0)
-				{
-					item_ptr->next_->previous_ = item_ptr->previous_;
-				}
-			
-				if (item_ptr->previous_ != 0)
-				{
-					item_ptr->previous_->next_ = item_ptr->next_;
-				}
-			
-				delete item_ptr;
-				
+				data.erase_after(prev);
 				return true;
 			}
+
+			prev = pos;
 		}
-		
 		return false;
+#else
+		DataIteratorPosition pos = std::find(data.begin(), data.end(), item);
+
+		if (pos != data.end())
+		{
+			data.erase(pos);
+
+			return true;
+		}
+
+		return false;
+#endif
 	}
 
 	template<typename Item>  
 	bool HashGridBox3<Item>::removeAll(const Item& item)
 	{
-		bool found = false;
-		DataItem* next_item = 0;
-		DataItem* item_ptr = first_item_;
-		
-		while(item_ptr != 0)
-		{
-			next_item = item_ptr->next_;
+		data.remove(item);
 
-			if (item_ptr->item_ == item)
-			{
-				if (item_ptr == first_item_)
-				{
-					first_item_ = first_item_->next_;
-				}
-				
-				if (item_ptr->next_ != 0)
-				{
-					item_ptr->next_->previous_ = item_ptr->previous_;
-				}
-			
-				if (item_ptr->previous_ != 0)
-				{
-					item_ptr->previous_->next_ = item_ptr->next_;
-				}
-			
-				delete item_ptr;
-				
-				found = true;
-			}
-			
-			item_ptr = next_item;
-		}
-
-		return found;
+		return true;
 	}
 
 	template <typename Item>
@@ -716,18 +649,7 @@ namespace BALL
 	template<typename Item>  
 	bool HashGridBox3<Item>::operator == (const HashGridBox3<Item>& box) const
 	{
-		const DataItem* a = first_item_;
-		const DataItem* b = box.first_item_;
-		
-		for (; a != 0 && b != 0; a = a->next_, b = b->next_)
-		{
-			if (a->item_ != b->item_)
-			{
-				return false;
-			}
-		}
-		
-		return (a == b);
+		return (data == box.data);
 	}
 
 	template<typename Item>  
@@ -741,35 +663,21 @@ namespace BALL
 	BALL_INLINE 
 	bool HashGridBox3<Item>::has(const Item& item) const
 	{
-		return (find(item) != 0);
+		return (std::find(data.begin(), data.end(), item) != data.end());
 	}
 
 	template<typename Item>  
 	BALL_INLINE 
 	bool HashGridBox3<Item>::isEmpty() const
 	{
-		return (first_item_ == 0);
+		return data.empty();
 	}
 
 	template<typename Item>  
 	bool HashGridBox3<Item>::isValid() const
 	{
-		Size size = 0;
-		DataItem* item = 0;
-		
-		for (item = first_item_; item != 0; item = item->next_)
-		{
-			++size;
-			
-			if (item->next_ == 0)
-			{
-				break;
-			}
-		}
-		
-		for (; item != 0; item = item->previous_, --size) {};
-		
-		return (size == 0);
+		// this is no longer required...
+		return true;
 	}
 
 	template<typename Item>  
@@ -784,20 +692,12 @@ namespace BALL
 		
 		BALL_DUMP_DEPTH(s, depth);
 		s << "  data:" << std::endl;
-		for (DataItem *item = first_item_; item != 0; item = item->next_)
+		for (typename DataContainer::const_iterator d_it = data.begin(); d_it != data.end(); ++d_it)
 		{
 			BALL_DUMP_DEPTH(s, depth);
-			s << "    " << item->item_ << std::endl;
+			s << "    " << *d_it << std::endl;
 		}
-		
-		BALL_DUMP_DEPTH(s, depth);
-		s << "  neighbor boxes:" << std::endl;
-		for (Position i=0; i<27; ++i)
-		{
-			BALL_DUMP_DEPTH(s, depth);
-			s << "    " << neighbours[i] << std::endl;
-		}
-		
+
 		BALL_DUMP_STREAM_SUFFIX(s);
 	}
 
@@ -811,9 +711,9 @@ namespace BALL
 
 		Processor::Result result;
 			
-		for (DataItem *item = first_item_; item != 0; item = item->next_)
+		for (typename DataContainer::iterator d_it = data.begin(); d_it != data.end(); ++d_it)
 		{
-			result = processor(item->item_);
+			result = processor(*d_it);
 
 			if (result <= Processor::BREAK)
 			{
@@ -834,9 +734,9 @@ namespace BALL
  
 		Processor::Result result;
 
-		for (Position i=0; i<27; ++i)
+		for (BoxIterator it = beginBox(); +it; ++it)
 		{
-			result = processor(*neighbours[i]);
+			result = processor(*it);
 
 			if (result <= Processor::BREAK)
 			{
@@ -1234,21 +1134,18 @@ namespace BALL
 		//_
 		Index getIndex_(const HashGridBox3<Item>& box) const;
 
-		/// update the neighbour information in the individual boxes
-		void setNeighbours_();
-
-		//_
-		HashGridBox3<Item>* box_;
 		//_
 		Vector3 origin_;
 		//_
 		Vector3 unit_;
 		//_
-		Size	dimension_x_;
+		Size dimension_x_;
 		//_
-		Size	dimension_y_;
+		Size dimension_y_;
 		//_
-		Size	dimension_z_;
+		Size dimension_z_;
+		//_
+		vector<HashGridBox3<Item> > box_;
 	};
 
 		
@@ -1257,8 +1154,7 @@ namespace BALL
 
 	template <typename Item>
 	HashGrid3<Item>::HashGrid3()
-		:	box_(0),
-			origin_(0,0,0),
+		: origin_(0,0,0),
 			unit_(0,0,0),
 			dimension_x_(0),
 			dimension_y_(0),
@@ -1271,52 +1167,43 @@ namespace BALL
 		(const Vector3 &originvector,
 		 Size dimension_x, Size dimension_y, Size dimension_z,
 		 float spacing_x, float spacing_y, float spacing_z)
-		:	box_(0),
-			origin_(originvector),
+		: origin_(originvector),
 			unit_(spacing_x, spacing_y, spacing_z),
 			dimension_x_(dimension_x),
 			dimension_y_(dimension_y),
-			dimension_z_(dimension_z)
+			dimension_z_(dimension_z),
+		  box_(dimension_x * dimension_y * dimension_z, HashGridBox3<Item>(this))
 	{
-		box_ = new HashGridBox3<Item>[dimension_x * dimension_y * dimension_z];
-		setNeighbours_();
 	}
 
 	template <typename Item>
 	HashGrid3<Item>::HashGrid3
 		(const Vector3& origin,
 		 Size dimension_x, Size dimension_y, Size dimension_z, float spacing)
-	 :	box_(0),
-			origin_(origin),
-			unit_(spacing, spacing, spacing),
-			dimension_x_(dimension_x),
-			dimension_y_(dimension_y),
-			dimension_z_(dimension_z)
+		: origin_(origin),
+		  unit_(spacing, spacing, spacing),
+		  dimension_x_(dimension_x),
+		  dimension_y_(dimension_y),
+		  dimension_z_(dimension_z),
+		  box_(dimension_x * dimension_y * dimension_z, HashGridBox3<Item>(this))
 	{
-		box_ = new HashGridBox3<Item>[dimension_x * dimension_y * dimension_z];
-		setNeighbours_();
 	}
 
 	// this constructor creates a linear array of HashGridBox3 objects.
 	template <typename Item>
 	HashGrid3<Item>::HashGrid3(const Vector3& origin, const Vector3& size,
 			float spacing)
-		:	box_(0),
-			origin_(origin),
+		: origin_(origin),
 			unit_(spacing, spacing, spacing),
 			dimension_x_((Size)(size.x / spacing + 1.0)),
 			dimension_y_((Size)(size.y / spacing + 1.0)),
-			dimension_z_((Size)(size.z / spacing + 1.0))
+			dimension_z_((Size)(size.z / spacing + 1.0)),
+		  box_(dimension_x_ * dimension_y_ * dimension_z_, HashGridBox3<Item>(this))
 	{
-		box_ = new HashGridBox3<Item>[dimension_x_ * dimension_y_ * dimension_z_];
-		setNeighbours_();
 	}
 
 	template <typename Item>
 	HashGrid3<Item>::HashGrid3(const HashGrid3<Item>& grid, bool deep)
-		:	box_(0),
-			origin_(),
-			unit_()
 	{
 		set(grid, deep);
 	}
@@ -1324,21 +1211,16 @@ namespace BALL
 	template <typename Item>
 	HashGrid3<Item>::~HashGrid3()
 	{
-		clear();
-		delete [] box_;
 	}
 
 	template <typename Item>
 	void HashGrid3<Item>::clear()
 	{
-		if (box_ != 0)
-		{
-			Size size = dimension_x_ * dimension_y_ * dimension_z_;
+		Size size = dimension_x_ * dimension_y_ * dimension_z_;
 
-			for (Position index = 0; index < (Position)size; ++index)
-			{
-				box_[index].clear();
-			}
+		for (Position index = 0; index < (Position)size; ++index)
+		{
+			box_[index].clear();
 		}
 	}
 
@@ -1392,58 +1274,38 @@ namespace BALL
 		(const Vector3& origin, const Vector3& unit,
 		 Size dimension_x, Size dimension_y, Size dimension_z)
 	{
-		clear();
-		if (box_ != 0)
-		{
-			delete [] box_;
-		}
 		origin_.set(origin);
 		unit_.set(unit);
 		dimension_x_ = dimension_x;
 		dimension_y_ = dimension_y;
 		dimension_z_ = dimension_z;
-		Size n = getSize();
-		box_ = new HashGridBox3<Item> [n];
-		setNeighbours_();
+		box_.assign(getSize(), HashGridBox3<Item>(this));
 	}
 
 	template <typename Item>
 	void HashGrid3<Item>::set(const Vector3& origin, float unit, Size size)
 	{
-		clear();
-		if (box_ != 0)
-		{
-			delete [] box_;
-		}
 		origin_.set(origin);
 		unit_.set(unit, unit, unit);
 		dimension_x_ = size;
 		dimension_y_ = size;
 		dimension_z_ = size;
-		box_ = new HashGridBox3<Item>[getSize()];
-		setNeighbours_();
+		box_.assign(getSize(), HashGridBox3<Item>(this));
 	}
 
 	template <typename Item>
 	void HashGrid3<Item>::set(const HashGrid3<Item>& grid, bool /* deep */)
 	{
-		set(grid.origin_, grid.unit_, grid.dimension_x_, grid.dimension_y_, grid.dimension_z_);
+		origin_.set(grid.origin_);
+		unit_.set(grid.unit_);
+		dimension_x_ = grid.dimension_x_;
+		dimension_y_ = grid.dimension_y_;
+		dimension_z_ = grid.dimension_z_;
+		box_ = grid.box_;
 
-		const HashGridBox3<Item>* sourcebox = grid.box_;
-		
-		HashGridBox3<Item>* targetbox = box_;
-		
-		const HashGridBox3<Item>* endbox = &grid.box_[grid.getSize()];
-		
-		for (; sourcebox < endbox; ++sourcebox, ++targetbox)
+		for(Position i = 0; i < box_.size(); ++i)
 		{
-			if (sourcebox->isEmpty() == false)
-			{
-				for (typename HashGridBox3<Item>::DataItem* item  = sourcebox->first_item_; item != 0; item = item->next_)
-				{
-					targetbox->insert(item->item_);
-				}
-			}
+			box_[i].setParent(this);
 		}
 	}
 
@@ -1730,7 +1592,7 @@ namespace BALL
 
 	template <typename Item>
 	BALL_INLINE 
-	bool HashGrid3<Item>::operator ==	(const HashGrid3<Item>& grid) const
+	bool HashGrid3<Item>::operator == (const HashGrid3<Item>& grid) const
 	{
 		if (getSize() != grid.getSize()
 				|| origin_ != grid.origin_
@@ -1741,22 +1603,8 @@ namespace BALL
 		{
 			return false;
 		}
-		
-		const HashGridBox3<Item>* abox = box_;
-		
-		const HashGridBox3<Item>* bbox = grid.box_;
-		
-		const HashGridBox3<Item>* endbox = &box_[getSize()];
-		
-		while (abox < endbox)
-		{
-			if (*abox++ != *bbox++)
-			{
-				return false;
-			}
-		}
-		
-		return true;
+
+		return box_ == grid.box_;
 	}
 
 	template <typename Item>
@@ -1849,9 +1697,9 @@ namespace BALL
 		for (Position i=0; i<27; ++i)
 		{
 			HashGridBox3<Item>* box = &box_[i];
-			for (typename HashGridBox3<Item>::DataItem *item = box->first_item_; item != 0; item = item->next_)
+			for (typename HashGridBox3<Item>::DataIterator *item = box->beginData(); +item; ++item)
 			{
-				result = processor(item->item_);
+				result = processor(*item);
 
 				if (result <= Processor::BREAK)
 				{
@@ -1891,48 +1739,15 @@ namespace BALL
 	BALL_INLINE 
 	Index HashGrid3<Item>::getIndex_(const HashGridBox3<Item>& box) const
 	{
-		if (&box < box_ ||& box >= &box_[getSize()])
+		if (&box < &box_[0] ||& box >= &box_[getSize()])
 		{
 			return INVALID_INDEX;
 		} 
 		else 
 		{
-			return (Index)(&box - box_);
+			return (Index)(&box - &box_[0]);
 		}
 	}
-
-	template <typename Item>
-	BALL_INLINE
-	void HashGrid3<Item>::setNeighbours_()
-	{
-		for (Position i=0; i<getSize(); ++i)
-		{
-			Position x, y, z;
-			getIndices(box_[i], x, y, z);
-
-			box_[i].neighbours[0] = &box_[i];
-
-			Position current_neighbour = 1;
-			// iterate over all the neighbouring boxes
-			for (int nx = x-1; (nx < (int)x+2); nx++)
-			{
-				for (int ny = y-1; (ny < (int)y+2); ny++)
-				{
-					for (int nz = z-1; (nz < (int)z+2); nz++)
-					{
-						HashGridBox3<Item>* nbox = getBox(nx, ny, nz);
-
-						if (nbox != &box_[i])
-						{
-							// NOTE: getBox returns 0 if indices are invalid, so this automatically works
-							box_[i].neighbours[current_neighbour++] = nbox;
-						}
-					}
-				}
-			}
-		}
-	}
-
 } // namespace BALL
 
 #endif // BALL_DATATYPE_HASHGRID_H
