@@ -369,9 +369,20 @@ namespace BALL
 			(const CoordinateType& r,	ValueType& ll, ValueType& lr, ValueType& ul, ValueType& ur) const
 			throw(Exception::OutOfGrid);
 									
+		/** Calculate the mean of the dataset
+		 		@return ValueType
+		*/
+		ValueType calculateMean() const;
+		
+		/** Calculate the standard deviation of the dataset
+		 		@return ValueType
+		*/
+		ValueType calculateSD() const;
+		
 		/** Write the grid contents in a (non-portable) binary format.
 		 		@exception FileNotFound thrown if file could not be written
 		*/
+		
 		void binaryWrite(const String& filename) const
 			throw(Exception::FileNotFound);
 
@@ -382,6 +393,7 @@ namespace BALL
 			throw(Exception::FileNotFound);
 		//@}
 	
+		
 		protected:
 			
 		/// The grid data
@@ -913,6 +925,36 @@ namespace BALL
 		return operator [] (position);
 	}
 
+	template <typename ValueType>
+	BALL_INLINE
+	ValueType TRegularData2D<ValueType>::calculateMean() const
+	{
+		Position data_points	= (size_.x * size_.y);
+		ValueType mean = 0;
+		for (Position i = 0; i < data_points; i++)
+		{
+		  mean += data_[i];
+		}
+		mean /= data_points;
+		return mean;
+	}
+	
+	template <typename ValueType>
+	BALL_INLINE
+	ValueType TRegularData2D<ValueType>::calculateSD() const
+	{
+		Position data_points	= (size_.x * size_.y);
+		ValueType stddev = 0;
+		ValueType mean = this->calculateMean();
+		for (Position i = 0; i < data_points; i++)
+		{
+			stddev += (pow(data_(i)-mean,2));
+		}
+		stddev /= (data_points-1);
+		stddev = sqrt(stddev);
+		return stddev;
+	}
+		
 	template <typename ValueType>
 	void TRegularData2D<ValueType>::clear()
 	{
