@@ -1,8 +1,6 @@
 // -*- Mode: C++; tab-width: 2; -*-
 // vi: set ts=2:
 //
-// $Id: PDBFile.h,v 1.35 2005/12/23 17:01:45 amoll Exp $
-//
 
 #ifndef BALL_FORMAT_PDBFILE_H
 #define BALL_FORMAT_PDBFILE_H
@@ -192,12 +190,8 @@ namespace BALL
 		/// Construct with options.
 		PDBFile(const Options& new_options);
 
-		/// Copy constructor
-		PDBFile(const PDBFile& file) throw(Exception::FileNotFound);
-		
 		/// Destructor
-		virtual ~PDBFile()
-			;
+		virtual ~PDBFile();
 		//@}
 
 		/** @name Assignment.
@@ -207,7 +201,7 @@ namespace BALL
 		/// Clear the stream state.
 		virtual void clear(int state);
 
-		/// Clear all members and close the file.
+		/// Clear all members.
 		virtual void clear();
 
 		//@}
@@ -225,6 +219,19 @@ namespace BALL
 		*/
 		void selectModel(Index index);
 
+		/**
+		 * This function allows to select the alternate location indicator
+		 * That should be parsed if one is specified. Default is 'A'.
+		 *
+		 * If other location indicators exist, but the specified one is missing
+		 * for an atom nothing will be parsed. Thus this option should be used
+		 * with caution.
+		 *
+		 * @throw IllegalArgument This exception is thrown if an invalid
+		 *        Location indicator (not a letter) was passed.
+		 */
+		void selectAltLocationIndicator(char c);
+
 		/// Return the model currently selected
 		Index getSelectedModel() const;
 
@@ -717,6 +724,14 @@ namespace BALL
 		void writeRecord_(const PDB::RecordSSBOND& helix);
 		/**	Write a CONECT record to the current stream */
 		void writeRecord_(const PDB::RecordCONECT& helix);
+		/**	Write a CRYST1 record to the current stream */
+		void writeRecord_(const PDB::RecordCRYST1& cryst1);
+		/**	Write a MTRIX1 record to the current stream */
+		void writeRecord_(const PDB::RecordMTRIX1& mtrix1);
+		/**	Write a MTRIX2 record to the current stream */
+		void writeRecord_(const PDB::RecordMTRIX2& mtrix2);
+		/**	Write a MTRIX3 record to the current stream */
+		void writeRecord_(const PDB::RecordMTRIX3& mtrix3);
 		
 		void writeAtom_(const PDB::Structure::AtomEntry& atom, PDB::AdditionalAtomInfo& cr, bool hetatm = false);
 		
@@ -738,6 +753,8 @@ namespace BALL
 		void writeSSBONDSection_(const PDB::Structure& structure);
 		void writeHYDBNDSection_(const PDB::Structure& structure);
 		void writeSLTBRGSection_(const PDB::Structure& structure);
+		void writeCRYST1Section_(const PDB::Structure& structure);
+		void writeMTRIXnSection_(const PDB::Structure& structure);
 
 		/**	Extract the atom and bond information from an atom container prior to writing a PDB file.
 				This method is called by \link write_ \endlink.
@@ -778,6 +795,7 @@ namespace BALL
 		SecStructList new_sheet_secstruc_list_;
 		SecStructList new_turn_secstruc_list_;
 
+		char alternate_location_indicator_;
 		PDB::AChar insertion_code_;
 		PDB::Character chain_ID_;
 		PDB::Integer sequence_number_;
