@@ -49,11 +49,11 @@
 
 namespace BALL 
 {
-	/**	Bond Order assignment processor
+	/**	Bond Order Assignment Processor
 			\ingroup StructureMiscellaneous
 	*/
 	
-	/** Assignment of bond orders from topology information.
+	/** \brief Assignment of bond orders from topology information.
 	 *  
 	 *  Called with default options the processor computes up to 
 	 *  \link Default::MAX_NUMBER_OF_SOLUTIONS Default::MAX_NUMBER_OF_SOLUTIONS\endlink 
@@ -80,7 +80,7 @@ namespace BALL
 	 *    	  i++;
 	 *      	bop.apply(i);
 	 *  	}
-	 *  	\endcode
+	 *  \endcode
 	 */
 	class BALL_EXPORT AssignBondOrderProcessor 
 		: public UnaryProcessor<AtomContainer> 
@@ -252,8 +252,6 @@ namespace BALL
 
 			//@}
 		
-			BALL_CREATE(AssignBondOrderProcessor);
-
 			/** @name	Constructors and Destructors
 			*/
 			//@{
@@ -261,9 +259,6 @@ namespace BALL
 			///	Default Constructor
 			AssignBondOrderProcessor();
 		
-			/// Copy Construcor
-			AssignBondOrderProcessor(const AssignBondOrderProcessor& abop);
-		
 			// constructor with parameter filename //TODO
 			//AssignBondOrderProcessor(const String& file_name) throw(Exception::FileNotFound);
 			
@@ -358,10 +353,10 @@ namespace BALL
 			 */
 			const System& getSolution(Position i) throw(Exception::IndexOverflow);
 
-			/**Returns the total charge of solution i.
+			/** Returns the total charge of solution i.
 			
-			 * @param   i index of the solution, whose charge should be computed. 
-				 @return  float - total charge of solution i.  
+			 	 	@param   i index of the solution, whose charge should be computed. 
+				 	@return  float - total charge of solution i.  
 			 */
 			float getTotalCharge(Position i)
 			{
@@ -378,9 +373,9 @@ namespace BALL
 			
 			/** Returns the total penalty of solution i.
 			 *
-			 * @param    i  index of the solution, whose penalty should be returned. 
-			 * @return  float -  total penalty of solution i.  
-			 * @see  Option:: BOND_LENGTH_WEIGHTING;
+			 * 	@param   i  	 index of the solution, whose penalty should be returned. 
+			 * 	@return  float -  total penalty of solution i.  
+			 * 	@see Option:: BOND_LENGTH_WEIGHTING;
 			 */
 			float getTotalPenalty(Position i)
 			{
@@ -453,7 +448,7 @@ namespace BALL
 			 *
 			 *  Ignores the options  \link MAX_NUMBER_OF_SOLUTIONS MAX_NUMBER_OF_SOLUTIONS \endlink and
 			 *											 \link COMPUTE_ALSO_NON_OPTIMAL_SOLUTIONS COMPUTE_ALSO_NON_OPTIMAL_SOLUTIONS\endlink .
-			 * @return bool - false if no further solution can be found.
+			 *  @return bool - false if no further solution can be found.
 			 */
 			bool computeNextSolution(bool apply_solution = true);
 
@@ -470,13 +465,6 @@ namespace BALL
 			float evaluatePenalty(AtomContainer* ac);
 			//@}
 			
-			/** @name Assignment
-			*/
-			//@{
-			/// assignment operator
-			AssignBondOrderProcessor& operator = (const AssignBondOrderProcessor& abop);
-			//@}
-
 			/** @name Public Attributes
 			*/
 			//@{
@@ -533,6 +521,7 @@ namespace BALL
 					int node_expansions;
 					int queue_size;
 					AssignBondOrderProcessor* parent;
+					AtomContainer* ac;
 			};
 			
 			// Nested class storing a priority queue entry for the A-STAR-Option
@@ -545,9 +534,6 @@ namespace BALL
 					// Default constructor
 					PQ_Entry_();
 								
-					// Copy constructor
-					PQ_Entry_(const PQ_Entry_& entry);
-
 					// Destructor
 					~PQ_Entry_();
 					
@@ -813,7 +799,8 @@ namespace BALL
 			vector<Solution_> solutions_;
 
 			// the original conformation before we computed anything
-			Solution_ starting_configuration_; 
+			// this is a vector because we can have multiple molecules...
+			vector<Solution_> starting_configuration_; 
 			
 			// the inverse of the atom type penalty normalization factor
 			float atom_type_normalization_factor_;
@@ -933,6 +920,8 @@ namespace BALL
 #ifdef BALL_HAS_LPSOLVE
 			lprec* ilp_;
 #endif
+			AssignBondOrderProcessor(const AssignBondOrderProcessor& abop);
+			AssignBondOrderProcessor& operator = (const AssignBondOrderProcessor& abop);
 		};
 
 } // namespace BALL 
