@@ -43,10 +43,10 @@
 
 #include <QtGui/QKeySequence>
 #include <QtGui/QMainWindow>
-#include <QtGui/qapplication.h>
-#include <QtGui/qmenubar.h> 
-#include <QtGui/qlabel.h>
-#include <QtCore/qtimer.h>
+#include <QtGui/QApplication>
+#include <QtGui/QMenuBar> 
+#include <QtGui/QLabel>
+#include <QtCore/QTimer>
 
 namespace BALL
 {
@@ -338,7 +338,7 @@ namespace BALL
 			HashSet<Composite*>& getSelection() ;
 
 			/// Get the selection (highlighted items) of the MolecularControl (not the selection with checkboxes)
-			List<Composite*>& getMolecularControlSelection();
+			std::list<Composite*>& getMolecularControlSelection();
 
 			/// If exactly one System is selected in the Control, return a pointer to this system, otherwise 0.
 			System* getSelectedSystem();
@@ -349,11 +349,6 @@ namespace BALL
 			/// Select a Composite recursive and add all Atom and AtomContainer objects to the selection.
 			void deselectCompositeRecursive(Composite* composite, bool first_call=false);
 
-			/** Clear Selection
-			 		Deselect all Composites and clear the selection list in the MainControl
-			*/
-			void clearSelection();
-
 			/** Print some informations for the selection in the statusbar.
 					Called by selectComposites_().
 					If one Atom is selected, its position is printed.
@@ -656,15 +651,6 @@ namespace BALL
 			/// See above
 			const String& getLoggingFilename() const;
 
-			/// Set the proxy for HTTP and FTP operations
-			void setProxy(const String& host, Position port);
-
-			/// Get the hostname for the proxy
-			String getProxy() const { return proxy_;}
-
-			/// Get the port for the proxy
-			Position getProxyPort() const { return proxy_port_;}
-			
 			///
 			bool isAboutToQuit() { return about_to_quit_;}
 		
@@ -734,6 +720,11 @@ namespace BALL
 			///
 			void complementSelection();
 
+			/** Clear Selection
+			 		Deselect all Composites and clear the selection list in the MainControl
+			*/
+			void clearSelection();
+
 			/** Last second cleanup.
 					This method will be called internally if the MainControl is about to be destroyed.
 					This method stores the preferences and finalizes all ModularWidget objects
@@ -864,7 +855,7 @@ namespace BALL
 			/*_ List with the selected composites of the control.
 					(Not the one with the checkboxes!)
 			*/
-			List<Composite*>						control_selection_;		
+			std::list<Composite*>						control_selection_;
 
 			/*_ Message label in the statusbar
 					\see setStatusbarText
@@ -891,7 +882,7 @@ namespace BALL
 					This list is modified by addModularWidget and
 					removeModularWidget.
 			*/
-			List<ModularWidget*>				modular_widgets_;
+			std::list<ModularWidget*>				modular_widgets_;
 		
 			QLabel*             simulation_icon_;
 			QLabel*             rep_label_;
@@ -912,11 +903,10 @@ namespace BALL
 			QTimer 							render_timer_;
 			Mutex 							composites_locked_mutex_;
 
-			String 							proxy_;
-			Position 						proxy_port_;
-
 			QAction* stop_simulation_action_;
+			QAction* fullscreen_action_;
 			QAction* complement_selection_action_;
+			QAction* clear_selection_action_;
 			QAction* open_action_;
 			QAction* save_project_action_;
 			QAction* preferences_action_;
@@ -925,7 +915,6 @@ namespace BALL
 
 			QAction* last_highlighted_menu_entry_;
 			HashMap<Position, QMenu*> id_to_menu_;
-			bool 					fullscreen_;
 			QPoint 				last_point_;
 			QSize 				last_size_;
 			QByteArray 		last_state_;
